import { StyleSheet } from "react-native";
import { capitalize } from "../../utils/utilsFunction";
import {
    responsiveHeight,
    responsiveWidth,
    responsiveFontSize
} from "react-native-responsive-dimensions";

export const spacing = (spacingType:string,value:number,direction = "",isScreen = true) => {
    if(isScreen){
        direction = capitalize(direction);
        const nameValue = `${spacingType}${direction}`;
        const nameKey = `${spacingType}${direction}${value.toString()}`;
        
        return StyleSheet.create({
            [nameKey]:{
                [nameValue]:value
            }
        });
    }
}

export const borderRadius = (value:number,direction = "",isScreen = true) => {
    if(isScreen){
        direction = capitalize(direction);
        const nameValue = `borderRadius${direction}`;
        const nameKey = `borderRadius${direction}${value.toString()}`;
        
        return  StyleSheet.create({
            [nameKey]:{
                [nameValue]:value
            }
        });
    }
}

export const dynamicWidthHeight = (
    width:number | null,
    height:number | null,
    responsiveHeightVerified:boolean = false,
    responsiveWidthValueVerified:boolean = false,
    isScreen:boolean = true
) => {
    if(isScreen){
        let nameKey:string = `dimension${width ?? ""}${height ?? ""}`;
        if(width != null && height == null){
            return  StyleSheet.create({
                [nameKey]:{
                    width:responsiveWidthValueVerified ? responsiveWidth(width) : width
                }
            });
        }
        else if(width == null && height != null){
            return  StyleSheet.create({
                [nameKey]:{
                    height:responsiveHeightVerified ? responsiveHeight(height) : height
                }
            });
        }
        else if(width != null && height != null){ 
            return  StyleSheet.create({
                [nameKey]:{
                    height:responsiveHeightVerified ? responsiveHeight(height) : height,
                    width:responsiveWidthValueVerified ? responsiveWidth(width) : width
                }
            });
        }
    }
}

export const fontSize = (value:number,isScreen:boolean = true,responsiveFontSizeCheck:boolean = false) => {
    if(isScreen){
        const nameKey = `fontSize${value.toString()}`;
        
        return  StyleSheet.create({
            [nameKey]:{
                fontSize:responsiveFontSizeCheck ? responsiveFontSize(value) : value
            }
        });
    }
}

export const fontWeight = (value:'normal' | 'bold' | '100' | '200' | '300' | '400' | '500' | '600' | '700' | '800' | '900' | undefined, isScreen:boolean = true) => {
    if(isScreen){
        const nameKey = `fontWeight${value}`;
        
        return  StyleSheet.create({
            [nameKey]:{
                fontWeight: value
            }
        });
    }
} 

export const normalShadow = (shadowColor:string) =>  StyleSheet.create({
    regularShadow:{
        shadowColor: shadowColor,
        shadowOffset: {
            width: 0,
            height: 4,
        },
        shadowOpacity: 0.32,
        shadowRadius: 5.46,
        elevation: 9, 
    }      
})
